@@ -1,4 +1,4 @@
-/*#include <QFile>
+#include <QFile>
 #include <QTextStream>
 #include <QTimer>
 #include <QStringList>
@@ -39,5 +39,3 @@ void aThread::processCoords(QString &data)
     emit deviceOrientation(x, y, z);
 }
 
-
-*/
