@@ -35,7 +35,7 @@ ExerciseWindow::ExerciseWindow(QWidget *parent) :
     label = new QLabel();
     label->setAlignment(Qt::AlignCenter);
 
-    btnShake = new QPushButton("Shake");
+    btnShake = new QPushButton("Done");
 
 
     connect(btnShake,SIGNAL(clicked()),this,SLOT(shaked()));
@@ -257,9 +257,6 @@ void ExerciseWindow::skipWait()
 
 void ExerciseWindow::checkAcc(QString x)
 {
-    if(x.toInt() > 2000)
-        qDebug() << "X: " + x;
-
     /*
     QSensor sensor(QProximitySensor);
     sensor->connect();
