@@ -12,11 +12,11 @@ HistoryWindow::HistoryWindow(QWidget *parent) :
 
     lstDates = new QListView();
     model = new QStandardItemModel(this);
-    dates = xml->getDates();
-    while(!dates.isEmpty())
-    {
-        model->appendRow(new QStandardItem(dates.takeFirst()));
-    }
+//    dates = xml->getDates();
+//    while(!dates.isEmpty())
+//    {
+//        model->appendRow(new QStandardItem(dates.takeFirst()));
+//    }
     lstDates->setModel(model);
 
     connect(lstDates,SIGNAL(clicked(QModelIndex)),this,SLOT(showExercises(QModelIndex)));
@@ -32,8 +32,8 @@ void HistoryWindow::showExercises(QModelIndex index)
 
 void HistoryWindow::load()
 {
-    model = new QStandardItemModel(this);
-
+//    model = new QStandardItemModel(this);
+    model->clear();
     dates = xml->getDates();
     while(!dates.isEmpty())
     {
