@@ -60,6 +60,7 @@ void XML::saveProgram(QString name, QList <QString> exercises)
     QFile file( "/home/user/MyDocs/program.xml" );
     file.open( QIODevice::ReadOnly );
     doc.setContent( &file );
+    file.remove();
 
     QDomElement root = doc.documentElement();
     if( root.tagName() != "programs" )
@@ -215,7 +216,7 @@ QList <QString> XML::loadSettings()
 void XML::saveDoneEx(QString group, QString name, QString kg, QString currentReps)
 {
     QDate date = QDate::currentDate();
-    QString dateString = date.toString("ddMMyy");
+    QString dateString = date.toString("dd-MM-yyyy");
 
     QDomDocument doc( "Exercises" );
     QFile file( "/home/user/MyDocs/history.xml" );
@@ -492,6 +493,7 @@ void XML::saveEx(QString name, QString group, QString muscle,
     QFile file( "/home/user/MyDocs/exercises.xml" );
     file.open( QIODevice::ReadOnly);
     doc.setContent( &file );
+    file.remove();
     file.close();
 
     //leta efter en vning med samma namn, isf ta bort den
@@ -546,6 +548,7 @@ void XML::saveCardio(QString name)
     QFile file( "/home/user/MyDocs/cardio.xml" );
     file.open( QIODevice::ReadOnly );
     doc.setContent( &file );
+    file.remove();
     file.close();
 
     //leta efter en vning med samma namn, isf ta bort den
@@ -727,6 +730,7 @@ void XML::saveFood(QString name, QString type, QString kcal)
     QFile file( "/home/user/MyDocs/ingredients.xml" );
     file.open( QIODevice::ReadOnly );
     doc.setContent( &file );
+    file.remove();
     file.close();
 
     //leta efter en vning med samma namn, isf ta bort den
@@ -786,7 +790,9 @@ void XML::updateLastWeight(QString name, QString weight, QString status, QString
       file.close();
       return;
     }
+    file.remove();
     file.close();
+
     QDomElement root = doc.documentElement();
     if( root.tagName() != "exercises" )
       return;
@@ -804,7 +810,7 @@ void XML::updateLastWeight(QString name, QString weight, QString status, QString
                 if(reps == "Low")
                 {
                     e.setAttribute("weight-low", weight);
-                    e.setAttribute("status-", status);
+                    e.setAttribute("status-low", status);
                 }
                 else if(reps == "Mid")
                 {
@@ -816,16 +822,13 @@ void XML::updateLastWeight(QString name, QString weight, QString status, QString
                     e.setAttribute("weight-high", weight);
                     e.setAttribute("status-high", status);
                 }
-
-
             }
         }
       }
       n = n.nextSibling();
    }
 
-    file.open( QIODevice::ReadWrite );
-
+    file.open( QIODevice::WriteOnly );
     QTextStream ts( &file );
     ts << doc.toString();
     file.close();
@@ -844,6 +847,7 @@ void XML::updateLastDistance(QString name, QString distance, QString min, QStrin
       file.close();
       return;
     }
+    file.remove();
     file.close();
     QDomElement root = doc.documentElement();
     if( root.tagName() != "exercises" )
@@ -974,13 +978,14 @@ QList<QString> XML::openEx(QString name)
 {
     QList<QString> readInfo;
 
-    QDomDocument doc( "Cardio" );
+    QDomDocument doc( "Exercises" );
     QFile file( "/home/user/MyDocs/exercises.xml" );
 
     if( !file.open( QIODevice::ReadOnly ) )
       return readInfo;
 
 
+
     if( !doc.setContent( &file ) )
     {
       file.close();
@@ -993,6 +998,7 @@ QList<QString> XML::openEx(QString name)
       return readInfo;
 
 
+
     QDomNode n = root.firstChild();
     while( !n.isNull() )
     {
@@ -1020,6 +1026,7 @@ QList<QString> XML::openEx(QString name)
       }
       n = n.nextSibling();
    }
+
     return readInfo;
 }
 
